package test.mrbool.com.mrbooltests;

import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Bundle;
import android.os.ParcelFileDescriptor;
import android.support.v7.app.AppCompatActivity;
import android.support.v7.widget.Toolbar;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.Toast;

import com.facebook.CallbackManager;
import com.facebook.FacebookCallback;
import com.facebook.FacebookException;
import com.facebook.FacebookSdk;
import com.facebook.login.LoginManager;
import com.facebook.login.LoginResult;
import com.facebook.share.ShareApi;
import com.facebook.share.model.SharePhoto;
import com.facebook.share.model.SharePhotoContent;

import java.io.FileDescriptor;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;

public class FacebookActivity extends AppCompatActivity {

    private static final int ACTION_PICK_IMAGE = 1;

    private CallbackManager callbackManager;
    private LoginManager manager;
    private ImageView imgTest;
    private EditText edtURL;
    private EditText edtSaySmth;
    private Bitmap thePic;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_facebook);
        Toolbar toolbar = (Toolbar) findViewById(R.id.toolbar);
        toolbar.setTitle("Facebook Test");
        setSupportActionBar(toolbar);

        imgTest = (ImageView) findViewById(R.id.imgTest);
        edtURL = (EditText) findViewById(R.id.edtURL);
        edtSaySmth = (EditText) findViewById(R.id.edtSaySmth);

        FacebookSdk.sdkInitialize(getApplicationContext());
        callbackManager = CallbackManager.Factory.create();

        List<String> permissionNeeds = Arrays.asList("publish_actions");

        manager = LoginManager.getInstance();
        manager.logInWithPublishPermissions(this, permissionNeeds);
        manager.registerCallback(callbackManager, new FacebookCallback<LoginResult>() {
            @Override
            public void onSuccess(LoginResult loginResult) {
                Toast.makeText(FacebookActivity.this, "Facebook login success!", Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onCancel() {
                Toast.makeText(FacebookActivity.this, "Facebook login canceled!", Toast.LENGTH_SHORT).show();
            }

            @Override
            public void onError(FacebookException exception) {
                Toast.makeText(FacebookActivity.this, "Facebook login error: " + exception.getMessage(), Toast.LENGTH_SHORT).show();
            }
        });
    }

    public void updateStatusClick(View view) {
        String text = edtSaySmth.getText().toString();
        String url = edtURL.getText().toString();

        SharePhoto photo = new SharePhoto.Builder()
                .setBitmap(thePic)
                .setImageUrl(Uri.parse(url))
                .setCaption(text)
                .build();

        SharePhotoContent content = new SharePhotoContent.Builder()
                .addPhoto(photo)
                .build();

        ShareApi.share(content, null);
        Toast.makeText(FacebookActivity.this, "Picture posted with success on Facebook!", Toast.LENGTH_SHORT).show();
    }

    public void loadImage(View view) {
        Intent photoPickerIntent = new Intent(Intent.ACTION_PICK);
        photoPickerIntent.setType("image/*");

        startActivityForResult(photoPickerIntent, ACTION_PICK_IMAGE);
    }

    @Override
    protected void onActivityResult(int requestCode, int responseCode, Intent data) {
        super.onActivityResult(requestCode, responseCode, data);
        if (requestCode == ACTION_PICK_IMAGE) {
            if (responseCode == RESULT_OK && data != null) {
                Uri selectedImage = data.getData();
                try {
                    thePic = getBitmapFromUri(selectedImage);
                } catch (IOException e) {
                    e.printStackTrace();
                }
                imgTest.setImageBitmap(thePic);
            }
        }
        callbackManager.onActivityResult(requestCode, responseCode, data);
    }

    private Bitmap getBitmapFromUri(Uri uri) throws IOException {
        ParcelFileDescriptor parcelFileDescriptor = getContentResolver().openFileDescriptor(uri, "r");
        FileDescriptor fileDescriptor = parcelFileDescriptor.getFileDescriptor();
        Bitmap image = BitmapFactory.decodeFileDescriptor(fileDescriptor);
        parcelFileDescriptor.close();
        return image;
    }
}